@@ -8,7 +8,9 @@ huge-count.pl --tokenlist --newline --split 20 testA1.hugecount testA1.data
 
 count2huge.pl --split 200 testA1.count A1  
 
-diff ./A1/count2huge.output ./testA1.hugecount/huge-count.output > ./A1/var
+if((-e ./A1/count2huge.output) && (-e ./testA1.hugecount/complete-huge-count.output)) then
+	diff ./A1/count2huge.output ./testA1.hugecount/complete-huge-count.output > ./A1/var;
+endif
 
 if( -z ./A1/var ) then
 	echo "Test Ok";
