@@ -147,11 +147,11 @@ total bigram count.
 
 INPUT PARAMS  : $count_values     .. Reference to an hash consisting
                                      of the count values passed to
-                                     the calcualteStatistic() method.
+                                     the calculateStatistic() method.
 
 RETURN VALUES : 1/undef           ..returns '1' to indicate success
                                     and an undefined(NULL) value to indicate
-                                    faliure.
+                                    failure.
 =cut
 
 sub computeObservedValues
@@ -232,7 +232,7 @@ INPUT PARAMS  :none
 
 RETURN VALUES : 1/undef           ..returns '1' to indicate success
                                     and an undefined(NULL) value to indicate
-                                    faliure.
+                                    failure.
 
 =cut
 
@@ -259,7 +259,7 @@ INPUT PARAMS  : $count_values     .. Reference to an hash consisting
 
 RETURN VALUES : 1/undef           ..returns '1' to indicate success
                                     and an undefined(NULL) value to indicate
-                                    faliure.
+                                    failure.
 
 =cut
 
@@ -372,7 +372,7 @@ Saiyam Kohli,                University of Minnesota Duluth
 
 =head1 HISTORY
 
-Last updated: $Id: 2D.pm,v 1.27 2006/06/21 11:10:52 saiyam_kohli Exp $
+Last updated: $Id: 2D.pm,v 1.28 2008/03/26 17:25:13 tpederse Exp $
 
 =head1 BUGS
 
